<?php

namespace Litecms\BusCategory\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\BusCategory\Models\BusCategories;

class BusCategoriesPolicy
{

    /**
     * Determine if the given user can view the bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function view(UserPolicy $user, BusCategories $bus_categories)
    {
        if ($user->canDo('bus_category.bus_categories.view') && $user->isAdmin()) {
            return true;
        }

        return $bus_categories->user_id == user_id() && $bus_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can create a bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bus_category.bus_categories.create');
    }

    /**
     * Determine if the given user can update the given bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function update(UserPolicy $user, BusCategories $bus_categories)
    {
        if ($user->canDo('bus_category.bus_categories.edit') && $user->isAdmin()) {
            return true;
        }

        return $bus_categories->user_id == user_id() && $bus_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, BusCategories $bus_categories)
    {
        return $bus_categories->user_id == user_id() && $bus_categories->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function verify(UserPolicy $user, BusCategories $bus_categories)
    {
        if ($user->canDo('bus_category.bus_categories.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given bus_categories.
     *
     * @param UserPolicy $user
     * @param BusCategories $bus_categories
     *
     * @return bool
     */
    public function approve(UserPolicy $user, BusCategories $bus_categories)
    {
        if ($user->canDo('bus_category.bus_categories.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
